import { AttributeValue, Attributes } from '@opentelemetry/api';
import { SpanKind } from '@opentelemetry/api';
import { SpanAttributes, TransactionSource } from '@sentry/types';
import { AbstractSpan } from '../types';
interface SpanDescription {
    op: string | undefined;
    description: string;
    source: TransactionSource;
    data?: Record<string, string | undefined>;
}
/**
 * Infer the op & description for a set of name, attributes and kind of a span.
 */
export declare function inferSpanData(name: string, attributes: SpanAttributes, kind: SpanKind): SpanDescription;
/**
 * Extract better op/description from an otel span.
 *
 * Based on https://github.com/open-telemetry/opentelemetry-collector-contrib/blob/7422ce2a06337f68a59b552b8c5a2ac125d6bae5/exporter/sentryexporter/sentry_exporter.go#L306
 */
export declare function parseSpanDescription(span: AbstractSpan): SpanDescription;
/** Only exported for tests. */
export declare function descriptionForHttpMethod({ name, kind, attributes }: {
    name: string;
    attributes: Attributes;
    kind: SpanKind;
}, httpMethod: AttributeValue): SpanDescription;
/** Exported for tests only */
export declare function getSanitizedUrl(attributes: Attributes, kind: SpanKind): {
    url: string | undefined;
    urlPath: string | undefined;
    query: string | undefined;
    fragment: string | undefined;
    hasRoute: boolean;
};
export {};
//# sourceMappingURL=parseSpanDescription.d.ts.map
